/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Used for rendering the footer of the Calendar. To define the footer template, nest an `<ng-template>` tag
 * with the `kendoCalendarFooterTemplate` directive inside the component tag. The template context is set to the
 * current component. To get a reference to the current `date` use the `let-date` directive. To get a reference to the
 * current active view use the `let-activeView` directive.
 *
 * For more examples, refer to the article on [templates]({% slug templates_calendar %}).
 *
 * @example
 * ```ts
 * _@Component({
 * selector: 'my-app',
 * styles: ['.custom { color: red; }'],
 * template: `
 *  <kendo-calendar>
 *    <ng-template kendoCalendarFooterTemplate let-date>
 *      <span class="custom">{{date}}</span>
 *    </ng-template>
 *  </kendo-calendar>
 * `
 * })
 * export class AppComponent { }
 * ```
 */
export declare class FooterTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<FooterTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FooterTemplateDirective, "[kendoCalendarFooterTemplate]", never, {}, {}, never, never, true, never>;
}
