/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, EventEmitter, OnChanges, OnDestroy, TemplateRef, Renderer2, NgZone, ElementRef } from '@angular/core';
import { CellContext } from './models/cell-context.interface';
import { ViewService } from './models/view-service.interface';
import { CalendarViewEnum } from './models/view.enum';
import { SelectionRangeEnd } from './models/selection-range-end.type';
import { SelectionRange } from './models/selection-range.interface';
import { BusViewService } from './services/bus-view.service';
import { DisabledDatesService } from './services/disabled-dates.service';
import { IntlService } from '@progress/kendo-angular-intl';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class ViewComponent implements OnChanges, OnDestroy {
    bus: BusViewService;
    intl: IntlService;
    private cdr;
    private element;
    private zone;
    private renderer;
    private disabledDatesService;
    allowReverse: boolean;
    showOtherMonthDays: boolean;
    direction: 'horizontal' | 'vertical';
    isActive: boolean;
    activeView: CalendarViewEnum;
    cellUID: string;
    focusedDate: Date;
    viewDate: Date;
    activeRangeEnd: SelectionRangeEnd;
    selectionRange: SelectionRange;
    min: Date;
    max: Date;
    selectedDates: Date[];
    get weekNumber(): boolean;
    set weekNumber(showWeekNumbers: boolean);
    viewIndex: number;
    templateRef: TemplateRef<any>;
    weekNumberTemplateRef: TemplateRef<any>;
    headerTitle: string;
    cellClick: EventEmitter<any>;
    weekNumberCellClick: EventEmitter<Date[]>;
    cellEnter: EventEmitter<Date>;
    cellLeave: EventEmitter<Date>;
    focusedCellId: EventEmitter<string>;
    get ariaHidden(): boolean;
    colSpan: number;
    data: CellContext[][];
    service: ViewService;
    title: string;
    private subscriptions;
    private showWeekNumbers;
    private domEvents;
    private currentCellIndex;
    constructor(bus: BusViewService, intl: IntlService, cdr: ChangeDetectorRef, element: ElementRef, zone: NgZone, renderer: Renderer2, disabledDatesService: DisabledDatesService);
    ngOnInit(): void;
    ngOnChanges(changes: any): void;
    ngOnDestroy(): void;
    isHorizontal(): boolean;
    isMonthView(): boolean;
    shouldRenderCellContent(cellCtx: CellContext): boolean;
    firstDate(rowCtx: CellContext[]): Date;
    getWeekNumber(date: Date): number;
    getWeekNumberContext(rowCtx: CellContext[]): CellContext;
    getStyles(context: CellContext): any;
    tableCellIndex(rowIndex: number, cellIndex: number): string;
    handleWeekNumberClick(week: CellContext[]): void;
    getMonthLabel(date: Date): string;
    private firstWeekDateContext;
    private updateData;
    private intlChange;
    private disabledDatesChange;
    private bindEvents;
    private clickHandler;
    private mouseLeaveHandler;
    private cellMouseoverHandler;
    private closestCell;
    private emitCellLeave;
    private cellByIndex;
    static ɵfac: i0.ɵɵFactoryDeclaration<ViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ViewComponent, "[kendoCalendarView]", never, { "allowReverse": { "alias": "allowReverse"; "required": false; }; "showOtherMonthDays": { "alias": "showOtherMonthDays"; "required": false; }; "direction": { "alias": "direction"; "required": false; }; "isActive": { "alias": "isActive"; "required": false; }; "activeView": { "alias": "activeView"; "required": false; }; "cellUID": { "alias": "cellUID"; "required": false; }; "focusedDate": { "alias": "focusedDate"; "required": false; }; "viewDate": { "alias": "viewDate"; "required": false; }; "activeRangeEnd": { "alias": "activeRangeEnd"; "required": false; }; "selectionRange": { "alias": "selectionRange"; "required": false; }; "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "selectedDates": { "alias": "selectedDates"; "required": false; }; "weekNumber": { "alias": "weekNumber"; "required": false; }; "viewIndex": { "alias": "viewIndex"; "required": false; }; "templateRef": { "alias": "templateRef"; "required": false; }; "weekNumberTemplateRef": { "alias": "weekNumberTemplateRef"; "required": false; }; "headerTitle": { "alias": "headerTitle"; "required": false; }; }, { "cellClick": "cellClick"; "weekNumberCellClick": "weekNumberCellClick"; "cellEnter": "cellEnter"; "cellLeave": "cellLeave"; "focusedCellId": "focusedCellId"; }, never, never, true, never>;
}
