/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterContentInit, OnDestroy } from '@angular/core';
import { DateRangeService } from './date-range.service';
import { DateInputSize } from '../common/models/size';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI DateRange component for Angular.
 *
 * @example
 * ```ts
 * _@Component({
 * selector: 'my-app',
 * template: `
 *  <kendo-daterange>
 *      <kendo-dateinput kendoDateRangeStartInput [(value)]="dateRange.start"></kendo-dateinput>
 *      <kendo-dateinput kendoDateRangeEndInput [(value)]="dateRange.end"></kendo-dateinput>
 *  </kendo-daterange>
 * `
 * })
 * export class AppComponent {
 *   public dateRange: any = { start: null, end: null };
 * }
 * ```
 */
export declare class DateRangeComponent implements AfterContentInit, OnDestroy {
    private dateRangeService;
    /**
     * @hidden
     *
     * TODO: Make visible when the Infinite Calendar is fixed to set properly the size option.
     * Sets the size of the component.
     *
     * The possible values are:
     * * `small`
     * * `medium` (Default)
     * * `large`
     * * `none`
     *
     */
    size: DateInputSize;
    /**
    * @hidden
    */
    keydown(event: any): void;
    wrapperClass: boolean;
    /**
     * @hidden
     */
    showDefault: boolean;
    private contentPopup;
    private get hasContentPopup();
    private subscription;
    constructor(dateRangeService: DateRangeService);
    ngAfterContentInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateRangeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateRangeComponent, "kendo-daterange", never, { "size": { "alias": "size"; "required": false; }; }, {}, ["contentPopup"], ["*"], true, never>;
}
