/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ElementRef, InjectionToken, OnChanges, OnDestroy, OnInit, AfterViewInit, Renderer2, NgZone } from '@angular/core';
import { Scrollable } from './models/scrollable.interface';
import { ScrollerService, PageAction, ScrollAction } from './services/scroller.service';
import { ScrollbarWidthService } from '@progress/kendo-angular-common';
import { Observable } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare const SCROLLER_FACTORY_TOKEN: InjectionToken<string>;
/**
 * @hidden
 */
export declare function DEFAULT_SCROLLER_FACTORY(observable: Observable<any>): ScrollerService;
/**
 * @hidden
 */
export declare enum ScrollDirection {
    Backward = 0,
    Forward = 1
}
/**
 * @hidden
 */
export declare class VirtualizationComponent implements OnChanges, OnInit, OnDestroy, AfterViewInit, Scrollable {
    container: ElementRef;
    renderer: Renderer2;
    zone: NgZone;
    protected scrollBarWidthService: ScrollbarWidthService;
    direction: 'horizontal' | 'vertical';
    itemHeight: number;
    itemWidth: number;
    topOffset: number;
    bottomOffset: number;
    maxScrollDifference: number;
    scrollOffsetSize: number;
    scrollDuration: number;
    skip: number;
    take: number;
    total: number;
    activeIndexChange: EventEmitter<number>;
    pageChange: EventEmitter<PageAction>;
    scrollChange: EventEmitter<ScrollAction>;
    wrapperClasses: boolean;
    get horizontalClass(): boolean;
    totalSize: number;
    get totalVertexLength(): any;
    get containerOffsetSize(): number;
    get containerScrollSize(): number;
    get containerScrollPosition(): number;
    private lastActiveIndex;
    private resolvedPromise;
    private scroller;
    private rowHeightService;
    private dispatcher;
    private scrollSubscription;
    private containerScrollSubscription;
    private animationSubscription;
    constructor(scrollerFactory: any, container: ElementRef, renderer: Renderer2, zone: NgZone, scrollBarWidthService: ScrollbarWidthService);
    ngOnChanges(changes: any): void;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    getContainerProperty(propertyName: string): number;
    activeIndex(): number;
    itemIndex(offset: number): number;
    itemOffset(index: number): number;
    isIndexVisible(index: number): boolean;
    isListScrolled(index: number): boolean;
    scrollTo(value: number): void;
    scrollToIndex(index: number): void;
    scrollToBottom(): void;
    animateToIndex(index: number): void;
    scrollRange(indexOffset: number, direction: ScrollDirection): any;
    scrollStep(start: number, end: number): number;
    scroll$(): Observable<any>;
    private initServices;
    private createRowHeightService;
    private emitActiveIndex;
    private containerMaxScroll;
    private getContainerScrollDirection;
    static ɵfac: i0.ɵɵFactoryDeclaration<VirtualizationComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<VirtualizationComponent, "kendo-virtualization", never, { "direction": { "alias": "direction"; "required": false; }; "itemHeight": { "alias": "itemHeight"; "required": false; }; "itemWidth": { "alias": "itemWidth"; "required": false; }; "topOffset": { "alias": "topOffset"; "required": false; }; "bottomOffset": { "alias": "bottomOffset"; "required": false; }; "maxScrollDifference": { "alias": "maxScrollDifference"; "required": false; }; "scrollOffsetSize": { "alias": "scrollOffsetSize"; "required": false; }; "scrollDuration": { "alias": "scrollDuration"; "required": false; }; "skip": { "alias": "skip"; "required": false; }; "take": { "alias": "take"; "required": false; }; "total": { "alias": "total"; "required": false; }; }, { "activeIndexChange": "activeIndexChange"; "pageChange": "pageChange"; "scrollChange": "scrollChange"; }, never, ["*"], true, never>;
}
